@@ -10,7 +10,6 @@ class BooleanField(models.BooleanField):
     def to_python(self,value):
         if isinstance(value,bytes):
             return value
-        print('called my one')
         if value in (True, False):
             # 1/0 are equal to True/False. bool() converts former to latter.
             return encrypter(bool(value))
@@ -246,7 +245,7 @@ class GenericIPAddressField(models.GenericIPAddressField):
         value = value.strip()
         if ':' in value:
             validators.validate_ipv46_address(value)
-            return clean_ipv6_address(value, self.unpack_ipv4, self.error_messages['invalid'])
+            return self.clean_ipv6_address(value, self.unpack_ipv4, self.error_messages['invalid'])
         validators.validate_ipv46_address(value)
         return value
 
@@ -458,7 +457,7 @@ class URLField(models.CharField):
         if isinstance(value,bytes):
             return value
         if isinstance(value, str):
-            url(value)
+            self.url(value)
             return encrypter(value)
         return encrypter(str(value))
 
